@@ -55,14 +55,11 @@ class NbCourse:
                     'authors': [],
                     'chapter_preview_only': [],
                     'license': None,
-                    'links': [{
-                        'title': 'Manual',
-                        'target': 'manual.html',
-                        'icon': {
-                            'path': 'img/Infobox_info_icon.svg',
-                            'width': '35px',
-                            }
-                        }]
+                    'links': {'manual': {
+                                    'title': 'Manual',
+                                    'target': 'manual.html',
+                                    }
+                              }
                     }
 
     def __init__(self, user_conf=None):
@@ -79,12 +76,18 @@ class NbCourse:
         self.conf['pages']['path'] = Path(self.conf['pages']['dir'])
         self.conf['output_path'] = Path(self.conf['output_dir'])
         if self.conf['local_reveal']:
-            nbcourse_libdir = Path(__file__).parents[1]
-            self.conf['reveal_path'] = nbcourse_libdir / Path('reveal.js')
+            self.conf['reveal_path'] = Path(__file__).parent / \
+                                       Path('reveal.js')
         self.notebooks = tuple(self.conf['nb']['path'].glob('*-*.ipynb'))
         if user_conf and not self.notebooks:
-            log.error("No notebooks found!\n" + \
-                      "Check 'nb:dir:' field in nbcourse.yml file.")
+            log.error("""
+No notebooks found!
+1. Check 'nb:dir:' field in nbcourse.yml file.
+2. Ensure that your notebooks are named using the pattern:
+   - "01-my_first_chapter_name.ipynb",
+   - "02-my_second_chapter_name.ipynb",
+   - etc.
+""")
             sys.exit()
         if self.conf['book']['file']:
             self.titlepage_path = self.conf['pages']['path'] / \
@@ -143,8 +146,10 @@ class NbCourse:
                 with open(config_file, 'r') as f:
                     user_conf_dict = yaml.safe_load(f)
             except FileNotFoundError as e:
-                log.error(f'"{e.filename}" file not found.\n' + \
-                          "Consider initializing an nbcourse project with 'nbcourse --init'.")
+                log.error(f'''"{e.filename}" file not found.
+Consider initializing an nbcourse project with:
+nbcourse --init\
+''')
                 sys.exit()
             sanitize(user_conf_dict)
             update_dict(conf, user_conf_dict)
@@ -222,7 +227,7 @@ class NbCourse:
             dst_files = [dst_path / file for file in files]
         else:  # dealing with single file, preserve directory tree
             src_files = [src_path]
-            rpath = src_path.relative_to(self.conf['nb']['dir'])
+            rpath = src_path.relative_to(self.conf['nb']['path'])
             dst_path = self.conf['output_path'] / rpath
             dst_files = [dst_path]
         return src_files, dst_path, dst_files
